@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 #
 # Proxy minion metaproxy modules
 #
-from __future__ import absolute_import, print_function, unicode_literals, with_statement
 
 import logging
 import os
@@ -12,7 +10,6 @@ import threading
 import traceback
 import types
 
-# Import Salt Libs
 # pylint: disable=3rd-party-module-not-gated
 import salt
 import salt.beacons
@@ -163,11 +160,11 @@ def post_master_init(self, master):
     )
 
     if (
-        "{0}.init".format(fq_proxyname) not in self.proxy
-        or "{0}.shutdown".format(fq_proxyname) not in self.proxy
+        "{}.init".format(fq_proxyname) not in self.proxy
+        or "{}.shutdown".format(fq_proxyname) not in self.proxy
     ):
         errmsg = (
-            "Proxymodule {0} is missing an init() or a shutdown() or both. ".format(
+            "Proxymodule {} is missing an init() or a shutdown() or both. ".format(
                 fq_proxyname
             )
             + "Check your proxymodule.  Salt-proxy aborted."
@@ -177,7 +174,7 @@ def post_master_init(self, master):
         raise SaltSystemExit(code=-1, msg=errmsg)
 
     self.module_executors = self.proxy.get(
-        "{0}.module_executors".format(fq_proxyname), lambda: []
+        "{}.module_executors".format(fq_proxyname), lambda: []
     )()
     proxy_init_fn = self.proxy[fq_proxyname + ".init"]
     proxy_init_fn(self.opts)
@@ -366,7 +363,7 @@ def target(cls, minion_instance, opts, data, connected):
             fq_proxyname = opts["proxy"]["proxytype"]
 
             minion_instance.module_executors = minion_instance.proxy.get(
-                "{0}.module_executors".format(fq_proxyname), lambda: []
+                "{}.module_executors".format(fq_proxyname), lambda: []
             )()
 
             proxy_init_fn = minion_instance.proxy[fq_proxyname + ".init"]
@@ -394,7 +391,7 @@ def thread_return(cls, minion_instance, opts, data):
     fn_ = os.path.join(minion_instance.proc_dir, data["jid"])
 
     salt.utils.process.appendproctitle(
-        "{0}._thread_return {1}".format(cls.__name__, data["jid"])
+        "{}._thread_return {}".format(cls.__name__, data["jid"])
     )
 
     sdata = {"pid": os.getpid()}
@@ -411,11 +408,11 @@ def thread_return(cls, minion_instance, opts, data):
     )
     allow_missing_funcs = any(
         [
-            minion_instance.executors["{0}.allow_missing_func".format(executor)](
+            minion_instance.executors["{}.allow_missing_func".format(executor)](
                 function_name
             )
             for executor in executors
-            if "{0}.allow_missing_func".format(executor) in minion_instance.executors
+            if "{}.allow_missing_func".format(executor) in minion_instance.executors
         ]
     )
     if function_name in minion_instance.functions or allow_missing_funcs is True:
@@ -458,11 +455,11 @@ def thread_return(cls, minion_instance, opts, data):
                 func = function_name
                 args, kwargs = data["arg"], data
             minion_instance.functions.pack["__context__"]["retcode"] = 0
-            if isinstance(executors, six.string_types):
+            if isinstance(executors, str):
                 executors = [executors]
             elif not isinstance(executors, list) or not executors:
                 raise SaltInvocationError(
-                    "Wrong executors specification: {0}. String or non-empty list expected".format(
+                    "Wrong executors specification: {}. String or non-empty list expected".format(
                         executors
                     )
                 )
@@ -471,10 +468,10 @@ def thread_return(cls, minion_instance, opts, data):
             log.trace("Executors list %s", executors)  # pylint: disable=no-member
 
             for name in executors:
-                fname = "{0}.execute".format(name)
+                fname = "{}.execute".format(name)
                 if fname not in minion_instance.executors:
                     raise SaltInvocationError(
-                        "Executor '{0}' is not available".format(name)
+                        "Executor '{}' is not available".format(name)
                     )
                 return_data = minion_instance.executors[fname](
                     opts, data, func, args, kwargs
@@ -492,9 +489,7 @@ def thread_return(cls, minion_instance, opts, data):
                         if not iret:
                             iret = []
                         iret.append(single)
-                    tag = tagify(
-                        [data["jid"], "prog", opts["id"], six.text_type(ind)], "job"
-                    )
+                    tag = tagify([data["jid"], "prog", opts["id"], str(ind)], "job")
                     event_data = {"return": single}
                     minion_instance._fire_master(event_data, tag)
                     ind += 1
@@ -521,9 +516,9 @@ def thread_return(cls, minion_instance, opts, data):
             ret["retcode"] = retcode
             ret["success"] = retcode == salt.defaults.exitcodes.EX_OK
         except CommandNotFoundError as exc:
-            msg = "Command required for '{0}' not found".format(function_name)
+            msg = "Command required for '{}' not found".format(function_name)
             log.debug(msg, exc_info=True)
-            ret["return"] = "{0}: {1}".format(msg, exc)
+            ret["return"] = "{}: {}".format(msg, exc)
             ret["out"] = "nested"
             ret["retcode"] = salt.defaults.exitcodes.EX_GENERIC
         except CommandExecutionError as exc:
@@ -533,7 +528,7 @@ def thread_return(cls, minion_instance, opts, data):
                 exc,
                 exc_info_on_loglevel=logging.DEBUG,
             )
-            ret["return"] = "ERROR: {0}".format(exc)
+            ret["return"] = "ERROR: {}".format(exc)
             ret["out"] = "nested"
             ret["retcode"] = salt.defaults.exitcodes.EX_GENERIC
         except SaltInvocationError as exc:
@@ -543,11 +538,11 @@ def thread_return(cls, minion_instance, opts, data):
                 exc,
                 exc_info_on_loglevel=logging.DEBUG,
             )
-            ret["return"] = "ERROR executing '{0}': {1}".format(function_name, exc)
+            ret["return"] = "ERROR executing '{}': {}".format(function_name, exc)
             ret["out"] = "nested"
             ret["retcode"] = salt.defaults.exitcodes.EX_GENERIC
         except TypeError as exc:
-            msg = "Passed invalid arguments to {0}: {1}\n{2}".format(
+            msg = "Passed invalid arguments to {}: {}\n{}".format(
                 function_name, exc, func.__doc__ or ""
             )
             log.warning(msg, exc_info_on_loglevel=logging.DEBUG)
@@ -556,15 +551,15 @@ def thread_return(cls, minion_instance, opts, data):
             ret["retcode"] = salt.defaults.exitcodes.EX_GENERIC
         except Exception:  # pylint: disable=broad-except
             msg = "The minion function caused an exception"
-            log.warning(msg, exc_info_on_loglevel=True)
+            log.warning(msg, exc_info=True)
             salt.utils.error.fire_exception(
                 salt.exceptions.MinionError(msg), opts, job=data
             )
-            ret["return"] = "{0}: {1}".format(msg, traceback.format_exc())
+            ret["return"] = "{}: {}".format(msg, traceback.format_exc())
             ret["out"] = "nested"
             ret["retcode"] = salt.defaults.exitcodes.EX_GENERIC
     else:
-        docs = minion_instance.functions["sys.doc"]("{0}*".format(function_name))
+        docs = minion_instance.functions["sys.doc"]("{}*".format(function_name))
         if docs:
             docs[function_name] = minion_instance.functions.missing_fun_string(
                 function_name
@@ -574,7 +569,7 @@ def thread_return(cls, minion_instance, opts, data):
             ret["return"] = minion_instance.functions.missing_fun_string(function_name)
             mod_name = function_name.split(".")[0]
             if mod_name in minion_instance.function_errors:
-                ret["return"] += " Possible reasons: '{0}'".format(
+                ret["return"] += " Possible reasons: '{}'".format(
                     minion_instance.function_errors[mod_name]
                 )
         ret["success"] = False
@@ -596,7 +591,7 @@ def thread_return(cls, minion_instance, opts, data):
 
     # Add default returners from minion config
     # Should have been coverted to comma-delimited string already
-    if isinstance(opts.get("return"), six.string_types):
+    if isinstance(opts.get("return"), str):
         if data["ret"]:
             data["ret"] = ",".join((data["ret"], opts["return"]))
         else:
@@ -604,7 +599,7 @@ def thread_return(cls, minion_instance, opts, data):
 
     log.debug("minion return: %s", ret)
     # TODO: make a list? Seems odd to split it this late :/
-    if data["ret"] and isinstance(data["ret"], six.string_types):
+    if data["ret"] and isinstance(data["ret"], str):
         if "ret_config" in data:
             ret["ret_config"] = data["ret_config"]
         if "ret_kwargs" in data:
@@ -612,7 +607,7 @@ def thread_return(cls, minion_instance, opts, data):
         ret["id"] = opts["id"]
         for returner in set(data["ret"].split(",")):
             try:
-                returner_str = "{0}.returner".format(returner)
+                returner_str = "{}.returner".format(returner)
                 if returner_str in minion_instance.returners:
                     minion_instance.returners[returner_str](ret)
                 else:
@@ -636,7 +631,7 @@ def thread_multi_return(cls, minion_instance, opts, data):
     fn_ = os.path.join(minion_instance.proc_dir, data["jid"])
 
     salt.utils.process.appendproctitle(
-        "{0}._thread_multi_return {1}".format(cls.__name__, data["jid"])
+        "{}._thread_multi_return {}".format(cls.__name__, data["jid"])
     )
 
     sdata = {"pid": os.getpid()}
@@ -735,7 +730,7 @@ def thread_multi_return(cls, minion_instance, opts, data):
         for returner in set(data["ret"].split(",")):
             ret["id"] = opts["id"]
             try:
-                minion_instance.returners["{0}.returner".format(returner)](ret)
+                minion_instance.returners["{}.returner".format(returner)](ret)
             except Exception as exc:  # pylint: disable=broad-except
                 log.error("The return failed for job %s: %s", data["jid"], exc)
 
@@ -785,7 +780,7 @@ def handle_decoded_payload(self, data):
             if len(self.jid_queue) > self.opts["minion_jid_queue_hwm"]:
                 self.jid_queue.pop(0)
 
-    if isinstance(data["fun"], six.string_types):
+    if isinstance(data["fun"], str):
         if data["fun"] == "sys.reload_modules":
             (
                 self.functions,
@@ -801,7 +796,7 @@ def handle_decoded_payload(self, data):
         process_count = len(salt.utils.minion.running(self.opts))
         while process_count >= process_count_max:
             log.warning(
-                "Maximum number of processes reached while executing jid {0}, waiting...".format(
+                "Maximum number of processes reached while executing jid {}, waiting...".format(
                     data["jid"]
                 )
             )
@@ -855,7 +850,7 @@ def target_load(self, load):
     # pre-processing on the master and this minion should not see the
     # publication if the master does not determine that it should.
     if "tgt_type" in load:
-        match_func = self.matchers.get("{0}_match.match".format(load["tgt_type"]), None)
+        match_func = self.matchers.get("{}_match.match".format(load["tgt_type"]), None)
         if match_func is None:
             return False
         if load["tgt_type"] in ("grain", "grain_pcre", "pillar"):
@@ -869,3 +864,12 @@ def target_load(self, load):
             return False
 
     return True
+
+
+# Main Minion Tune In
+def tune_in(self, start=True):
+    """
+    Lock onto the publisher. This is the main event loop for the minion
+    :rtype : None
+    """
+    super(ProxyMinion, self).tune_in(start=start)
