@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Pkgutil support for Solaris
 
 .. important::
@@ -7,7 +7,7 @@ Pkgutil support for Solaris
     minion, and it is using a different module (or gives an error similar to
     *'pkg.install' is not available*), see :ref:`here
     <module-provider-override>`.
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
 
 # Import python libs
@@ -22,21 +22,24 @@ from salt.exceptions import CommandExecutionError, MinionError
 from salt.ext import six
 
 # Define the module's virtual name
-__virtualname__ = 'pkgutil'
+__virtualname__ = "pkgutil"
 
 
 def __virtual__():
-    '''
+    """
     Set the virtual pkg module if the os is Solaris
-    '''
-    if __grains__['os_family'] == 'Solaris':
+    """
+    if __grains__["os_family"] == "Solaris":
         return __virtualname__
-    return (False, 'The pkgutil execution module cannot be loaded: '
-            'only available on Solaris systems.')
+    return (
+        False,
+        "The pkgutil execution module cannot be loaded: "
+        "only available on Solaris systems.",
+    )
 
 
 def refresh_db():
-    '''
+    """
     Updates the pkgutil repo database (pkgutil -U)
 
     CLI Example:
@@ -44,14 +47,14 @@ def refresh_db():
     .. code-block:: bash
 
         salt '*' pkgutil.refresh_db
-    '''
+    """
     # Remove rtag file to keep multiple refreshes from happening in pkg states
     salt.utils.pkg.clear_rtag(__opts__)
-    return __salt__['cmd.retcode']('/opt/csw/bin/pkgutil -U') == 0
+    return __salt__["cmd.retcode"]("/opt/csw/bin/pkgutil -U") == 0
 
 
 def upgrade_available(name):
-    '''
+    """
     Check if there is an upgrade available for a certain package
 
     CLI Example:
@@ -59,23 +62,22 @@ def upgrade_available(name):
     .. code-block:: bash
 
         salt '*' pkgutil.upgrade_available CSWpython
-    '''
+    """
     version_num = None
-    cmd = '/opt/csw/bin/pkgutil -c --parse --single {0}'.format(
-        name)
-    out = __salt__['cmd.run_stdout'](cmd)
+    cmd = "/opt/csw/bin/pkgutil -c --parse --single {0}".format(name)
+    out = __salt__["cmd.run_stdout"](cmd)
     if out:
         version_num = out.split()[2].strip()
     if version_num:
         if version_num == "SAME":
-            return ''
+            return ""
         else:
             return version_num
-    return ''
+    return ""
 
 
 def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
-    '''
+    """
     List all available package upgrades on this system
 
     CLI Example:
@@ -83,14 +85,13 @@ def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
     .. code-block:: bash
 
         salt '*' pkgutil.list_upgrades
-    '''
+    """
     if salt.utils.data.is_true(refresh):
         refresh_db()
     upgrades = {}
-    lines = __salt__['cmd.run_stdout'](
-        '/opt/csw/bin/pkgutil -A --parse').splitlines()
+    lines = __salt__["cmd.run_stdout"]("/opt/csw/bin/pkgutil -A --parse").splitlines()
     for line in lines:
-        comps = line.split('\t')
+        comps = line.split("\t")
         if comps[2] == "SAME":
             continue
         if comps[2] == "not installed":
@@ -100,7 +101,7 @@ def list_upgrades(refresh=True, **kwargs):  # pylint: disable=W0613
 
 
 def upgrade(refresh=True):
-    '''
+    """
     Upgrade all of the packages to the latest available version.
 
     Returns a dict containing the changes::
@@ -113,7 +114,7 @@ def upgrade(refresh=True):
     .. code-block:: bash
 
         salt '*' pkgutil.upgrade
-    '''
+    """
     if salt.utils.data.is_true(refresh):
         refresh_db()
 
@@ -121,15 +122,15 @@ def upgrade(refresh=True):
 
     # Install or upgrade the package
     # If package is already installed
-    cmd = '/opt/csw/bin/pkgutil -yu'
-    __salt__['cmd.run_all'](cmd)
-    __context__.pop('pkg.list_pkgs', None)
+    cmd = "/opt/csw/bin/pkgutil -yu"
+    __salt__["cmd.run_all"](cmd)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     return salt.utils.data.compare_dicts(old, new)
 
 
 def list_pkgs(versions_as_list=False, **kwargs):
-    '''
+    """
     List the packages currently installed as a dict::
 
         {'<package_name>': '<version>'}
@@ -140,43 +141,43 @@ def list_pkgs(versions_as_list=False, **kwargs):
 
         salt '*' pkg.list_pkgs
         salt '*' pkg.list_pkgs versions_as_list=True
-    '''
+    """
     versions_as_list = salt.utils.data.is_true(versions_as_list)
     # 'removed' not yet implemented or not applicable
-    if salt.utils.data.is_true(kwargs.get('removed')):
+    if salt.utils.data.is_true(kwargs.get("removed")):
         return {}
 
-    if 'pkg.list_pkgs' in __context__:
+    if "pkg.list_pkgs" in __context__:
         if versions_as_list:
-            return __context__['pkg.list_pkgs']
+            return __context__["pkg.list_pkgs"]
         else:
-            ret = copy.deepcopy(__context__['pkg.list_pkgs'])
-            __salt__['pkg_resource.stringify'](ret)
+            ret = copy.deepcopy(__context__["pkg.list_pkgs"])
+            __salt__["pkg_resource.stringify"](ret)
             return ret
 
     ret = {}
-    cmd = '/usr/bin/pkginfo -x'
+    cmd = "/usr/bin/pkginfo -x"
 
     # Package information returned two lines per package. On even-offset
     # lines, the package name is in the first column. On odd-offset lines, the
     # package version is in the second column.
-    lines = __salt__['cmd.run'](cmd).splitlines()
+    lines = __salt__["cmd.run"](cmd).splitlines()
     for index, line in enumerate(lines):
         if index % 2 == 0:
             name = line.split()[0].strip()
         if index % 2 == 1:
             version_num = line.split()[1].strip()
-            __salt__['pkg_resource.add_pkg'](ret, name, version_num)
+            __salt__["pkg_resource.add_pkg"](ret, name, version_num)
 
-    __salt__['pkg_resource.sort_pkglist'](ret)
-    __context__['pkg.list_pkgs'] = copy.deepcopy(ret)
+    __salt__["pkg_resource.sort_pkglist"](ret)
+    __context__["pkg.list_pkgs"] = copy.deepcopy(ret)
     if not versions_as_list:
-        __salt__['pkg_resource.stringify'](ret)
+        __salt__["pkg_resource.stringify"](ret)
     return ret
 
 
 def version(*names, **kwargs):
-    '''
+    """
     Returns a version if the package is installed, else returns an empty string
 
     CLI Example:
@@ -184,12 +185,12 @@ def version(*names, **kwargs):
     .. code-block:: bash
 
         salt '*' pkgutil.version CSWpython
-    '''
-    return __salt__['pkg_resource.version'](*names, **kwargs)
+    """
+    return __salt__["pkg_resource.version"](*names, **kwargs)
 
 
 def latest_version(*names, **kwargs):
-    '''
+    """
     Return the latest version of the named package available for upgrade or
     installation. If more than one package name is specified, a dict of
     name/version pairs is returned.
@@ -203,23 +204,23 @@ def latest_version(*names, **kwargs):
 
         salt '*' pkgutil.latest_version CSWpython
         salt '*' pkgutil.latest_version <package1> <package2> <package3> ...
-    '''
-    refresh = salt.utils.data.is_true(kwargs.pop('refresh', True))
+    """
+    refresh = salt.utils.data.is_true(kwargs.pop("refresh", True))
 
     if not names:
-        return ''
+        return ""
     ret = {}
     # Initialize the dict with empty strings
     for name in names:
-        ret[name] = ''
+        ret[name] = ""
 
     # Refresh before looking for the latest version available
     if refresh:
         refresh_db()
 
     pkgs = list_pkgs()
-    cmd = '/opt/csw/bin/pkgutil -a --parse {0}'.format(' '.join(names))
-    output = __salt__['cmd.run_all'](cmd).get('stdout', '').splitlines()
+    cmd = "/opt/csw/bin/pkgutil -a --parse {0}".format(" ".join(names))
+    output = __salt__["cmd.run_all"](cmd).get("stdout", "").splitlines()
     for line in output:
         try:
             name, version_rev = line.split()[1:3]
@@ -227,11 +228,9 @@ def latest_version(*names, **kwargs):
             continue
 
         if name in names:
-            cver = pkgs.get(name, '')
-            nver = version_rev.split(',')[0]
-            if not cver or salt.utils.versions.compare(ver1=cver,
-                                                       oper='<',
-                                                       ver2=nver):
+            cver = pkgs.get(name, "")
+            nver = version_rev.split(",")[0]
+            if not cver or salt.utils.versions.compare(ver1=cver, oper="<", ver2=nver):
                 # Remove revision for version comparison
                 ret[name] = version_rev
 
@@ -240,12 +239,15 @@ def latest_version(*names, **kwargs):
         return ret[names[0]]
     return ret
 
+
 # available_version is being deprecated
-available_version = salt.utils.functools.alias_function(latest_version, 'available_version')
+available_version = salt.utils.functools.alias_function(
+    latest_version, "available_version"
+)
 
 
 def install(name=None, refresh=False, version=None, pkgs=None, **kwargs):
-    '''
+    """
     Install packages using the pkgutil tool.
 
     CLI Example:
@@ -274,15 +276,13 @@ def install(name=None, refresh=False, version=None, pkgs=None, **kwargs):
 
         {'<package>': {'old': '<old-version>',
                        'new': '<new-version>'}}
-    '''
+    """
     if refresh:
         refresh_db()
 
     try:
         # Ignore 'sources' argument
-        pkg_params = __salt__['pkg_resource.parse_targets'](name,
-                                                            pkgs,
-                                                            **kwargs)[0]
+        pkg_params = __salt__["pkg_resource.parse_targets"](name, pkgs, **kwargs)[0]
     except MinionError as exc:
         raise CommandExecutionError(exc)
 
@@ -296,18 +296,18 @@ def install(name=None, refresh=False, version=None, pkgs=None, **kwargs):
         if pkgver is None:
             targets.append(param)
         else:
-            targets.append('{0}-{1}'.format(param, pkgver))
+            targets.append("{0}-{1}".format(param, pkgver))
 
-    cmd = '/opt/csw/bin/pkgutil -yu {0}'.format(' '.join(targets))
+    cmd = "/opt/csw/bin/pkgutil -yu {0}".format(" ".join(targets))
     old = list_pkgs()
-    __salt__['cmd.run_all'](cmd)
-    __context__.pop('pkg.list_pkgs', None)
+    __salt__["cmd.run_all"](cmd)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     return salt.utils.data.compare_dicts(old, new)
 
 
 def remove(name=None, pkgs=None, **kwargs):
-    '''
+    """
     Remove a package and all its dependencies which are not in use by other
     packages.
 
@@ -333,9 +333,9 @@ def remove(name=None, pkgs=None, **kwargs):
         salt '*' pkg.remove <package name>
         salt '*' pkg.remove <package1>,<package2>,<package3>
         salt '*' pkg.remove pkgs='["foo", "bar"]'
-    '''
+    """
     try:
-        pkg_params = __salt__['pkg_resource.parse_targets'](name, pkgs)[0]
+        pkg_params = __salt__["pkg_resource.parse_targets"](name, pkgs)[0]
     except MinionError as exc:
         raise CommandExecutionError(exc)
 
@@ -343,15 +343,15 @@ def remove(name=None, pkgs=None, **kwargs):
     targets = [x for x in pkg_params if x in old]
     if not targets:
         return {}
-    cmd = '/opt/csw/bin/pkgutil -yr {0}'.format(' '.join(targets))
-    __salt__['cmd.run_all'](cmd)
-    __context__.pop('pkg.list_pkgs', None)
+    cmd = "/opt/csw/bin/pkgutil -yr {0}".format(" ".join(targets))
+    __salt__["cmd.run_all"](cmd)
+    __context__.pop("pkg.list_pkgs", None)
     new = list_pkgs()
     return salt.utils.data.compare_dicts(old, new)
 
 
 def purge(name=None, pkgs=None, **kwargs):
-    '''
+    """
     Package purges are not supported, this function is identical to
     ``remove()``.
 
@@ -377,5 +377,5 @@ def purge(name=None, pkgs=None, **kwargs):
         salt '*' pkg.purge <package name>
         salt '*' pkg.purge <package1>,<package2>,<package3>
         salt '*' pkg.purge pkgs='["foo", "bar"]'
-    '''
+    """
     return remove(name=name, pkgs=pkgs)
