@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Manage ruby installations with rbenv. rbenv is supported on Linux and macOS.
 rbenv doesn't work on Windows (and isn't really necessary on Windows as there is
 no system Ruby on Windows). On Windows, the RubyInstaller and/or Pik are both
@@ -8,13 +8,14 @@ good alternatives to work with multiple versions of Ruby on the same box.
 http://misheska.com/blog/2013/06/15/using-rbenv-to-manage-multiple-versions-of-ruby/
 
 .. versionadded:: 0.16.0
-'''
+"""
 
 # Import python libs
-from __future__ import absolute_import, unicode_literals, print_function
+from __future__ import absolute_import, print_function, unicode_literals
+
+import logging
 import os
 import re
-import logging
 
 # Import Salt libs
 import salt.utils.args
@@ -29,22 +30,23 @@ from salt.ext import six
 # Set up logger
 log = logging.getLogger(__name__)
 
-__func_alias__ = {
-    'list_': 'list'
-}
+__func_alias__ = {"list_": "list"}
 
 __opts__ = {
-    'rbenv.root': None,
-    'rbenv.build_env': None,
+    "rbenv.root": None,
+    "rbenv.build_env": None,
 }
 
 
 def __virtual__():
-    '''
+    """
     Only work on POSIX-like systems
-    '''
+    """
     if salt.utils.platform.is_windows():
-        return (False, 'The rbenv execution module failed to load: only available on non-Windows systems.')
+        return (
+            False,
+            "The rbenv execution module failed to load: only available on non-Windows systems.",
+        )
     return True
 
 
@@ -52,7 +54,7 @@ def _shlex_split(s):
     # from python:salt.utils.args.shlex_split: passing None for s will read
     # the string to split from standard input.
     if s is None:
-        ret = salt.utils.args.shlex_split('')
+        ret = salt.utils.args.shlex_split("")
     else:
         ret = salt.utils.args.shlex_split(s)
 
@@ -68,25 +70,27 @@ def _parse_env(env):
         env = {}
 
     for bad_env_key in (x for x, y in six.iteritems(env) if y is None):
-        log.error('Environment variable \'%s\' passed without a value. '
-                  'Setting value to an empty string', bad_env_key)
-        env[bad_env_key] = ''
+        log.error(
+            "Environment variable '%s' passed without a value. "
+            "Setting value to an empty string",
+            bad_env_key,
+        )
+        env[bad_env_key] = ""
 
     return env
 
 
 def _rbenv_bin(runas=None):
     path = _rbenv_path(runas)
-    return '{0}/bin/rbenv'.format(path)
+    return "{0}/bin/rbenv".format(path)
 
 
 def _rbenv_path(runas=None):
     path = None
-    if runas in (None, 'root'):
-        path = __salt__['config.option']('rbenv.root') or '/usr/local/rbenv'
+    if runas in (None, "root"):
+        path = __salt__["config.option"]("rbenv.root") or "/usr/local/rbenv"
     else:
-        path = __salt__['config.option']('rbenv.root') \
-            or '~{0}/.rbenv'.format(runas)
+        path = __salt__["config.option"]("rbenv.root") or "~{0}/.rbenv".format(runas)
 
     return os.path.expanduser(path)
 
@@ -99,20 +103,16 @@ def _rbenv_exec(command, env=None, runas=None, ret=None):
     path = _rbenv_path(runas)
 
     environ = _parse_env(env)
-    environ['RBENV_ROOT'] = path
+    environ["RBENV_ROOT"] = path
 
-    result = __salt__['cmd.run_all'](
-        [binary] + command,
-        runas=runas,
-        env=environ
-    )
+    result = __salt__["cmd.run_all"]([binary] + command, runas=runas, env=environ)
 
     if isinstance(ret, dict):
         ret.update(result)
         return ret
 
-    if result['retcode'] == 0:
-        return result['stdout']
+    if result["retcode"] == 0:
+        return result["stdout"]
     else:
         return False
 
@@ -121,43 +121,46 @@ def _install_rbenv(path, runas=None):
     if os.path.isdir(path):
         return True
 
-    cmd = ['git', 'clone', 'https://github.com/sstephenson/rbenv.git', path]
-    return __salt__['cmd.retcode'](cmd, runas=runas, python_shell=False) == 0
+    cmd = ["git", "clone", "https://github.com/rbenv/rbenv.git", path]
+    return __salt__["cmd.retcode"](cmd, runas=runas, python_shell=False) == 0
 
 
 def _install_ruby_build(path, runas=None):
-    path = '{0}/plugins/ruby-build'.format(path)
+    path = "{0}/plugins/ruby-build".format(path)
     if os.path.isdir(path):
         return True
 
-    cmd = ['git', 'clone',
-           'https://github.com/sstephenson/ruby-build.git', path]
-    return __salt__['cmd.retcode'](cmd, runas=runas, python_shell=False) == 0
+    cmd = ["git", "clone", "https://github.com/rbenv/ruby-build.git", path]
+    return __salt__["cmd.retcode"](cmd, runas=runas, python_shell=False) == 0
 
 
 def _update_rbenv(path, runas=None):
     if not os.path.isdir(path):
         return False
 
-    return __salt__['cmd.retcode'](['git', 'pull'],
-                                   runas=runas,
-                                   cwd=path,
-                                   python_shell=False) == 0
+    return (
+        __salt__["cmd.retcode"](
+            ["git", "pull"], runas=runas, cwd=path, python_shell=False
+        )
+        == 0
+    )
 
 
 def _update_ruby_build(path, runas=None):
-    path = '{0}/plugins/ruby-build'.format(path)
+    path = "{0}/plugins/ruby-build".format(path)
     if not os.path.isdir(path):
         return False
 
-    return __salt__['cmd.retcode'](['git', 'pull'],
-                                   runas=runas,
-                                   cwd=path,
-                                   python_shell=False) == 0
+    return (
+        __salt__["cmd.retcode"](
+            ["git", "pull"], runas=runas, cwd=path, python_shell=False
+        )
+        == 0
+    )
 
 
 def install(runas=None, path=None):
-    '''
+    """
     Install rbenv systemwide
 
     CLI Example:
@@ -165,14 +168,14 @@ def install(runas=None, path=None):
     .. code-block:: bash
 
         salt '*' rbenv.install
-    '''
+    """
     path = path or _rbenv_path(runas)
     path = os.path.expanduser(path)
     return _install_rbenv(path, runas) and _install_ruby_build(path, runas)
 
 
 def update(runas=None, path=None):
-    '''
+    """
     Updates the current versions of rbenv and ruby-build
 
     runas
@@ -184,7 +187,7 @@ def update(runas=None, path=None):
     .. code-block:: bash
 
         salt '*' rbenv.update
-    '''
+    """
     path = path or _rbenv_path(runas)
     path = os.path.expanduser(path)
 
@@ -192,7 +195,7 @@ def update(runas=None, path=None):
 
 
 def is_installed(runas=None):
-    '''
+    """
     Check if rbenv is installed
 
     CLI Example:
@@ -200,12 +203,12 @@ def is_installed(runas=None):
     .. code-block:: bash
 
         salt '*' rbenv.is_installed
-    '''
-    return __salt__['cmd.has_exec'](_rbenv_bin(runas))
+    """
+    return __salt__["cmd.has_exec"](_rbenv_bin(runas))
 
 
 def install_ruby(ruby, runas=None):
-    '''
+    """
     Install a ruby implementation.
 
     ruby
@@ -229,28 +232,28 @@ def install_ruby(ruby, runas=None):
     .. code-block:: bash
 
         salt '*' rbenv.install_ruby 2.0.0-p0
-    '''
-    ruby = re.sub(r'^ruby-', '', ruby)
+    """
+    ruby = re.sub(r"^ruby-", "", ruby)
 
     env = None
     env_list = []
 
-    if __grains__['os'] in ('FreeBSD', 'NetBSD', 'OpenBSD'):
-        env_list.append('MAKE=gmake')
+    if __grains__["os"] in ("FreeBSD", "NetBSD", "OpenBSD"):
+        env_list.append("MAKE=gmake")
 
-    if __salt__['config.get']('rbenv:build_env'):
-        env_list.append(__salt__['config.get']('rbenv:build_env'))
-    elif __salt__['config.option']('rbenv.build_env'):
-        env_list.append(__salt__['config.option']('rbenv.build_env'))
+    if __salt__["config.get"]("rbenv:build_env"):
+        env_list.append(__salt__["config.get"]("rbenv:build_env"))
+    elif __salt__["config.option"]("rbenv.build_env"):
+        env_list.append(__salt__["config.option"]("rbenv.build_env"))
 
     if env_list:
-        env = ' '.join(env_list)
+        env = " ".join(env_list)
 
     ret = {}
-    ret = _rbenv_exec(['install', ruby], env=env, runas=runas, ret=ret)
-    if ret is not False and ret['retcode'] == 0:
+    ret = _rbenv_exec(["install", ruby], env=env, runas=runas, ret=ret)
+    if ret is not False and ret["retcode"] == 0:
         rehash(runas=runas)
-        return ret['stderr']
+        return ret["stderr"]
     else:
         # Cleanup the failed installation so it doesn't list as installed
         uninstall_ruby(ruby, runas=runas)
@@ -258,7 +261,7 @@ def install_ruby(ruby, runas=None):
 
 
 def uninstall_ruby(ruby, runas=None):
-    '''
+    """
     Uninstall a ruby implementation.
 
     ruby
@@ -274,14 +277,14 @@ def uninstall_ruby(ruby, runas=None):
     .. code-block:: bash
 
         salt '*' rbenv.uninstall_ruby 2.0.0-p0
-    '''
-    ruby = re.sub(r'^ruby-', '', ruby)
-    _rbenv_exec(['uninstall', '--force', ruby], runas=runas)
+    """
+    ruby = re.sub(r"^ruby-", "", ruby)
+    _rbenv_exec(["uninstall", "--force", ruby], runas=runas)
     return True
 
 
 def versions(runas=None):
-    '''
+    """
     List the installed versions of ruby
 
     CLI Example:
@@ -289,13 +292,13 @@ def versions(runas=None):
     .. code-block:: bash
 
         salt '*' rbenv.versions
-    '''
-    ret = _rbenv_exec(['versions', '--bare'], runas=runas)
+    """
+    ret = _rbenv_exec(["versions", "--bare"], runas=runas)
     return [] if ret is False else ret.splitlines()
 
 
 def default(ruby=None, runas=None):
-    '''
+    """
     Returns or sets the currently defined default ruby
 
     ruby
@@ -309,17 +312,17 @@ def default(ruby=None, runas=None):
 
         salt '*' rbenv.default
         salt '*' rbenv.default 2.0.0-p0
-    '''
+    """
     if ruby:
-        _rbenv_exec(['global', ruby], runas=runas)
+        _rbenv_exec(["global", ruby], runas=runas)
         return True
     else:
-        ret = _rbenv_exec(['global'], runas=runas)
-        return '' if ret is False else ret.strip()
+        ret = _rbenv_exec(["global"], runas=runas)
+        return "" if ret is False else ret.strip()
 
 
 def list_(runas=None):
-    '''
+    """
     List the installable versions of ruby
 
     runas
@@ -331,19 +334,19 @@ def list_(runas=None):
     .. code-block:: bash
 
         salt '*' rbenv.list
-    '''
+    """
     ret = []
-    output = _rbenv_exec(['install', '--list'], runas=runas)
+    output = _rbenv_exec(["install", "--list"], runas=runas)
     if output:
         for line in output.splitlines():
-            if line == 'Available versions:':
+            if line == "Available versions:":
                 continue
             ret.append(line.strip())
     return ret
 
 
 def rehash(runas=None):
-    '''
+    """
     Run ``rbenv rehash`` to update the installed shims
 
     runas
@@ -355,13 +358,13 @@ def rehash(runas=None):
     .. code-block:: bash
 
         salt '*' rbenv.rehash
-    '''
-    _rbenv_exec(['rehash'], runas=runas)
+    """
+    _rbenv_exec(["rehash"], runas=runas)
     return True
 
 
 def do(cmdline, runas=None, env=None):
-    '''
+    """
     Execute a ruby command with rbenv's shims from the user or the system
 
     CLI Example:
@@ -370,12 +373,12 @@ def do(cmdline, runas=None, env=None):
 
         salt '*' rbenv.do 'gem list bundler'
         salt '*' rbenv.do 'gem list bundler' deploy
-    '''
+    """
     if not cmdline:
         # This is a positional argument so this should never happen, but this
         # will handle cases where someone explicitly passes a false value for
         # cmdline.
-        raise SaltInvocationError('Command must be specified')
+        raise SaltInvocationError("Command must be specified")
 
     path = _rbenv_path(runas)
     if not env:
@@ -384,11 +387,15 @@ def do(cmdline, runas=None, env=None):
     # NOTE: Env vars (and their values) need to be str type on both Python 2
     # and 3. The code below first normalizes all path components to unicode to
     # stitch them together, and then converts the result back to a str type.
-    env[str('PATH')] = salt.utils.stringutils.to_str(   # future lint: disable=blacklisted-function
-        os.pathsep.join((
-            salt.utils.path.join(path, 'shims'),
-            salt.utils.stringutils.to_unicode(os.environ['PATH'])
-        ))
+    env[
+        str("PATH")
+    ] = salt.utils.stringutils.to_str(  # future lint: disable=blacklisted-function
+        os.pathsep.join(
+            (
+                salt.utils.path.join(path, "shims"),
+                salt.utils.stringutils.to_unicode(os.environ["PATH"]),
+            )
+        )
     )
 
     try:
@@ -396,22 +403,17 @@ def do(cmdline, runas=None, env=None):
     except AttributeError:
         cmdauth = salt.utils.args.shlex_split(six.text_type(cmdline))
 
-    result = __salt__['cmd.run_all'](
-        cmdline,
-        runas=runas,
-        env=env,
-        python_shell=False
-    )
+    result = __salt__["cmd.run_all"](cmdline, runas=runas, env=env, python_shell=False)
 
-    if result['retcode'] == 0:
+    if result["retcode"] == 0:
         rehash(runas=runas)
-        return result['stdout']
+        return result["stdout"]
     else:
         return False
 
 
 def do_with_ruby(ruby, cmdline, runas=None):
-    '''
+    """
     Execute a ruby command with rbenv's shims using a specific ruby version
 
     CLI Example:
@@ -420,12 +422,12 @@ def do_with_ruby(ruby, cmdline, runas=None):
 
         salt '*' rbenv.do_with_ruby 2.0.0-p0 'gem list bundler'
         salt '*' rbenv.do_with_ruby 2.0.0-p0 'gem list bundler' runas=deploy
-    '''
+    """
     if not cmdline:
         # This is a positional argument so this should never happen, but this
         # will handle cases where someone explicitly passes a false value for
         # cmdline.
-        raise SaltInvocationError('Command must be specified')
+        raise SaltInvocationError("Command must be specified")
 
     try:
         cmdline = salt.utils.args.shlex_split(cmdline)
@@ -434,7 +436,7 @@ def do_with_ruby(ruby, cmdline, runas=None):
 
     env = {}
     if ruby:
-        env['RBENV_VERSION'] = ruby
+        env["RBENV_VERSION"] = ruby
         cmd = cmdline
     else:
         cmd = cmdline
