@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-r'''
+r"""
 Display Pony output data structure
 ==================================
 
@@ -39,29 +39,37 @@ Example output:
                █▄▄██████   █▄▄██████
                  █▄▄▄▄█       █▄▄▄▄█
 
-'''
+
+CLI Example:
+
+.. code-block:: bash
+
+    salt '*' foo.bar --out=pony
+"""
 
 # Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
+
 import subprocess
 
 # Import Salt libs
-import salt.utils.locales
+import salt.utils.data
 import salt.utils.path
 
-
-__virtualname__ = 'pony'
+__virtualname__ = "pony"
 
 
 def __virtual__():
-    if salt.utils.path.which('ponysay'):
+    if salt.utils.path.which("ponysay"):
         return __virtualname__
     return False
 
 
 def output(data, **kwargs):  # pylint: disable=unused-argument
-    '''
+    """
     Mane function
-    '''
-    high_out = __salt__['highstate'](data)
-    return subprocess.check_output(['ponysay', salt.utils.locales.sdecode(high_out)])  # pylint: disable=E0598
+    """
+    high_out = __salt__["highstate"](data)
+    return subprocess.check_output(
+        ["ponysay", salt.utils.data.decode(high_out)]
+    )  # pylint: disable=E0598
