@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 General management functions for salt, tools like seeing what hosts are up
 and what hosts are down
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import operator
@@ -16,7 +13,6 @@ import tempfile
 import time
 import uuid
 
-# Import salt libs
 import salt.client
 import salt.client.ssh
 import salt.key
@@ -28,9 +24,6 @@ import salt.utils.versions
 import salt.version
 import salt.wheel
 from salt.exceptions import SaltClientError, SaltSystemExit
-
-# Import 3rd-party libs
-from salt.ext import six
 from salt.ext.six.moves.urllib.request import urlopen as _urlopen
 
 FINGERPRINT_REGEX = re.compile(r"^([a-f0-9]{2}:){15}([a-f0-9]{2})$")
@@ -63,7 +56,7 @@ def _ping(tgt, tgt_type, timeout, gather_job_timeout):
     ):
 
         if fn_ret:
-            for mid, _ in six.iteritems(fn_ret):
+            for mid, _ in fn_ret.items():
                 log.debug("minion '%s' returned from ping", mid)
                 returned.add(mid)
 
@@ -78,6 +71,7 @@ def status(
 ):
     """
     .. versionchanged:: 2017.7.0
+
         The ``expr_form`` argument has been renamed to ``tgt_type``, earlier
         releases must use ``expr_form``.
 
@@ -162,6 +156,7 @@ def down(
 ):
     """
     .. versionchanged:: 2017.7.0
+
         The ``expr_form`` argument has been renamed to ``tgt_type``, earlier
         releases must use ``expr_form``.
 
@@ -175,7 +170,6 @@ def down(
         salt-run manage.down
         salt-run manage.down removekeys=True
         salt-run manage.down tgt="webservers" tgt_type="nodegroup"
-
     """
     ret = status(
         output=False,
@@ -196,6 +190,7 @@ def up(
 ):  # pylint: disable=C0103
     """
     .. versionchanged:: 2017.7.0
+
         The ``expr_form`` argument has been renamed to ``tgt_type``, earlier
         releases must use ``expr_form``.
 
@@ -219,24 +214,10 @@ def up(
     return ret
 
 
-def _show_ip_migration(show_ip, show_ipv4):
-    if show_ipv4 is not None:
-        salt.utils.versions.warn_until(
-            "Sodium",
-            "The 'show_ipv4' argument has been renamed to 'show_ip' as"
-            "it now also includes IPv6 addresses for IPv6-connected"
-            "minions.",
-        )
-        return show_ipv4
-    return show_ip
-
-
-def list_state(subset=None, show_ip=False, show_ipv4=None):
+def list_state(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are up according to Salt's presence
     detection (no commands will be sent to minions)
@@ -253,8 +234,6 @@ def list_state(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.list_state
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
-
     # Always return 'present' for 0MQ for now
     # TODO: implement other states support for 0MQ
     ckminions = salt.utils.minions.CkMinions(__opts__)
@@ -265,12 +244,10 @@ def list_state(subset=None, show_ip=False, show_ipv4=None):
     return connected
 
 
-def list_not_state(subset=None, show_ip=False, show_ipv4=None):
+def list_not_state(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are NOT up according to Salt's presence
     detection (no commands will be sent to minions)
@@ -287,7 +264,6 @@ def list_not_state(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.list_not_state
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     connected = list_state(subset=None, show_ip=show_ip)
 
     key = salt.key.get_key(__opts__)
@@ -301,11 +277,9 @@ def list_not_state(subset=None, show_ip=False, show_ipv4=None):
     return not_connected
 
 
-def present(subset=None, show_ip=False, show_ipv4=None):
+def present(subset=None, show_ip=False):
     """
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are up according to Salt's presence
     detection (no commands will be sent to minions)
@@ -322,16 +296,13 @@ def present(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.present
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_state(subset=subset, show_ip=show_ip)
 
 
-def not_present(subset=None, show_ip=False, show_ipv4=None):
+def not_present(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.5.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are NOT up according to Salt's presence
     detection (no commands will be sent)
@@ -348,16 +319,13 @@ def not_present(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.not_present
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_not_state(subset=subset, show_ip=show_ip)
 
 
-def joined(subset=None, show_ip=False, show_ipv4=None):
+def joined(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are up according to Salt's presence
     detection (no commands will be sent to minions)
@@ -374,16 +342,13 @@ def joined(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.joined
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_state(subset=subset, show_ip=show_ip)
 
 
-def not_joined(subset=None, show_ip=False, show_ipv4=None):
+def not_joined(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are NOT up according to Salt's presence
     detection (no commands will be sent)
@@ -400,16 +365,13 @@ def not_joined(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.not_joined
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_not_state(subset=subset, show_ip=show_ip)
 
 
-def allowed(subset=None, show_ip=False, show_ipv4=None):
+def allowed(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are up according to Salt's presence
     detection (no commands will be sent to minions)
@@ -426,16 +388,13 @@ def allowed(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.allowed
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_state(subset=subset, show_ip=show_ip)
 
 
-def not_allowed(subset=None, show_ip=False, show_ipv4=None):
+def not_allowed(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are NOT up according to Salt's presence
     detection (no commands will be sent)
@@ -452,16 +411,13 @@ def not_allowed(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.not_allowed
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_not_state(subset=subset, show_ip=show_ip)
 
 
-def alived(subset=None, show_ip=False, show_ipv4=None):
+def alived(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are up according to Salt's presence
     detection (no commands will be sent to minions)
@@ -478,16 +434,13 @@ def alived(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.alived
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_state(subset=subset, show_ip=show_ip)
 
 
-def not_alived(subset=None, show_ip=False, show_ipv4=None):
+def not_alived(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are NOT up according to Salt's presence
     detection (no commands will be sent)
@@ -504,16 +457,13 @@ def not_alived(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.not_alived
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_not_state(subset=subset, show_ip=show_ip)
 
 
-def reaped(subset=None, show_ip=False, show_ipv4=None):
+def reaped(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are up according to Salt's presence
     detection (no commands will be sent to minions)
@@ -530,16 +480,13 @@ def reaped(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.reaped
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_state(subset=subset, show_ip=show_ip)
 
 
-def not_reaped(subset=None, show_ip=False, show_ipv4=None):
+def not_reaped(subset=None, show_ip=False):
     """
     .. versionadded:: 2015.8.0
     .. versionchanged:: 2019.2.0
-        The 'show_ipv4' argument has been renamed to 'show_ip' as it now
-        includes IPv6 addresses for IPv6-connected minions.
 
     Print a list of all minions that are NOT up according to Salt's presence
     detection (no commands will be sent)
@@ -556,13 +503,13 @@ def not_reaped(subset=None, show_ip=False, show_ipv4=None):
 
         salt-run manage.not_reaped
     """
-    show_ip = _show_ip_migration(show_ip, show_ipv4)
     return list_not_state(subset=subset, show_ip=show_ip)
 
 
 def safe_accept(target, tgt_type="glob"):
     """
     .. versionchanged:: 2017.7.0
+
         The ``expr_form`` argument has been renamed to ``tgt_type``, earlier
         releases must use ``expr_form``.
 
@@ -581,7 +528,7 @@ def safe_accept(target, tgt_type="glob"):
     ret = ssh_client.cmd(target, "key.finger", tgt_type=tgt_type)
 
     failures = {}
-    for minion, finger in six.iteritems(ret):
+    for minion, finger in ret.items():
         if not FINGERPRINT_REGEX.match(finger):
             failures[minion] = finger
         else:
@@ -592,11 +539,11 @@ def safe_accept(target, tgt_type="glob"):
                 del ret[minion]
                 continue
             elif minion not in pending:
-                failures[minion] = "Minion key {0} not found by salt-key".format(minion)
+                failures[minion] = "Minion key {} not found by salt-key".format(minion)
             elif pending[minion] != finger:
                 failures[minion] = (
-                    "Minion key {0} does not match the key in "
-                    "salt-key: {1}".format(finger, pending[minion])
+                    "Minion key {} does not match the key in "
+                    "salt-key: {}".format(finger, pending[minion])
                 )
             else:
                 subprocess.call(["salt-key", "-qya", minion])
@@ -606,14 +553,14 @@ def safe_accept(target, tgt_type="glob"):
 
     if failures:
         print("safe_accept failed on the following minions:")
-        for minion, message in six.iteritems(failures):
+        for minion, message in failures.items():
             print(minion)
             print("-" * len(minion))
             print(message)
             print("")
 
     __jid_event__.fire_event(
-        {"message": "Accepted {0:d} keys".format(len(ret))}, "progress"
+        {"message": "Accepted {:d} keys".format(len(ret))}, "progress"
     )
     return ret, failures
 
@@ -755,9 +702,7 @@ def bootstrap(
 
         salt-run manage.bootstrap hosts='host1,host2'
         salt-run manage.bootstrap hosts='host1,host2' version='v0.17'
-        salt-run manage.bootstrap hosts='host1,host2' version='v0.17' \
-            script='https://bootstrap.saltstack.com/develop'
-
+        salt-run manage.bootstrap hosts='host1,host2' version='v0.17' script='https://bootstrap.saltstack.com/develop'
     """
     if script is None:
         script = "https://bootstrap.saltstack.com"
@@ -778,7 +723,7 @@ def bootstrap(
     for host in hosts.split(","):
         client_opts["tgt"] = host
         client_opts["selected_target_option"] = "glob"
-        tmp_dir = "{0}-{1}/".format(tmp_dir.rstrip("/"), uuid.uuid4())
+        tmp_dir = "{}-{}/".format(tmp_dir.rstrip("/"), uuid.uuid4())
         deploy_command = os.path.join(tmp_dir, "deploy.sh")
         try:
             client_opts["argv"] = ["file.makedirs", tmp_dir, "mode=0700"]
@@ -786,8 +731,8 @@ def bootstrap(
             client_opts["argv"] = [
                 "http.query",
                 script,
-                "backend={0}".format(http_backend),
-                "text_out={0}".format(deploy_command),
+                "backend={}".format(http_backend),
+                "text_out={}".format(deploy_command),
             ]
             salt.client.ssh.SSH(client_opts).run()
             client_opts["argv"] = [
@@ -799,7 +744,7 @@ def bootstrap(
             client_opts["argv"] = ["file.remove", tmp_dir]
             salt.client.ssh.SSH(client_opts).run()
         except SaltSystemExit as exc:
-            log.error(six.text_type(exc))
+            log.error(str(exc))
 
 
 def bootstrap_psexec(
@@ -902,7 +847,7 @@ objShell.Exec("{1}{2}")"""
     vb_saltexec = "saltinstall.exe"
     vb_saltexec_args = " /S /minion-name=%COMPUTERNAME%"
     if master:
-        vb_saltexec_args += " /master={0}".format(master)
+        vb_saltexec_args += " /master={}".format(master)
 
     # One further thing we need to do; the Windows Salt minion is pretty
     # self-contained, except for the Microsoft Visual C++ 2008 runtime.
