@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Manage Launch Configurations
 
 .. versionadded:: 2014.7.0
@@ -97,39 +97,46 @@ and autoscale groups are completely dependent on each other.
             keyid: GKTADJGHEIQSXMKKRBJ08H
             key: askdjghsdfjkghWupUjasdflkdfklgjsdfjajkghs
             region: us-east-1
-'''
-from __future__ import absolute_import
+"""
+from __future__ import absolute_import, print_function, unicode_literals
+
 from salt.exceptions import SaltInvocationError
 
 
 def __virtual__():
-    '''
+    """
     Only load if boto is available.
-    '''
-    return 'boto_lc' if 'boto_asg.exists' in __salt__ else False
+    """
+    if "boto_asg.exists" in __salt__:
+        return "boto_lc"
+    return (False, "boto_asg module could not be loaded")
 
 
 def present(
-        name,
-        image_id,
-        key_name=None,
-        security_groups=None,
-        user_data=None,
-        cloud_init=None,
-        instance_type='m1.small',
-        kernel_id=None,
-        ramdisk_id=None,
-        block_device_mappings=None,
-        instance_monitoring=False,
-        spot_price=None,
-        instance_profile_name=None,
-        ebs_optimized=False,
-        associate_public_ip_address=None,
-        region=None,
-        key=None,
-        keyid=None,
-        profile=None):
-    '''
+    name,
+    image_id,
+    key_name=None,
+    vpc_id=None,
+    vpc_name=None,
+    security_groups=None,
+    user_data=None,
+    cloud_init=None,
+    instance_type="m1.small",
+    kernel_id=None,
+    ramdisk_id=None,
+    block_device_mappings=None,
+    delete_on_termination=None,
+    instance_monitoring=False,
+    spot_price=None,
+    instance_profile_name=None,
+    ebs_optimized=False,
+    associate_public_ip_address=None,
+    region=None,
+    key=None,
+    keyid=None,
+    profile=None,
+):
+    """
     Ensure the launch configuration exists.
 
     name
@@ -143,6 +150,16 @@ def present(
         Name of the EC2 key pair to use for instances. Key must exist or
         creation of the launch configuration will fail.
 
+    vpc_id
+        The VPC id where the security groups are defined. Only necessary when
+        using named security groups that exist outside of the default VPC.
+        Mutually exclusive with vpc_name.
+
+    vpc_name
+        Name of the VPC where the security groups are defined. Only Necessary
+        when using named security groups that exist outside of the default VPC.
+        Mutually exclusive with vpc_id.
+
     security_groups
         List of Names or security group id’s of the security groups with which
         to associate the EC2 instances or VPC instances, respectively. Security
@@ -152,8 +169,9 @@ def present(
         The user data available to launched EC2 instances.
 
     cloud_init
-        A dict of cloud_init configuration. Currently supported values:
-        scripts, cloud-config. Mutually exclusive with user_data.
+        A dict of cloud_init configuration. Currently supported keys:
+        boothooks, scripts and cloud-config.
+        Mutually exclusive with user_data.
 
     instance_type
         The instance type. ex: m1.small.
@@ -169,24 +187,29 @@ def present(
         with volume_type, delete_on_termination, iops, size, encrypted,
         snapshot_id.
 
-    volume_type
-        Indicates what volume type to use. Valid values are standard, io1, gp2.
-        Default is standard.
+        volume_type
+            Indicates what volume type to use. Valid values are standard, io1, gp2.
+            Default is standard.
 
-    delete_on_termination
-        Indicates whether to delete the volume on instance termination (true) or
-        not (false).
+        delete_on_termination
+            Whether the volume should be explicitly marked for deletion when its instance is
+            terminated (True), or left around (False).  If not provided, or None is explicitly passed,
+            the default AWS behaviour is used, which is True for ROOT volumes of instances, and
+            False for all others.
 
-    iops
-        For Provisioned IOPS (SSD) volumes only. The number of I/O operations per
-        second (IOPS) to provision for the volume.
+        iops
+            For Provisioned IOPS (SSD) volumes only. The number of I/O operations per
+            second (IOPS) to provision for the volume.
 
-    encrypted
-        Indicates whether the volume should be encrypted. Encrypted EBS volumes must
-        be attached to instances that support Amazon EBS encryption. Volumes that are
-        created from encrypted snapshots are automatically encrypted. There is no way
-        to create an encrypted volume from an unencrypted snapshot or an unencrypted
-        volume from an encrypted snapshot.
+        size
+            Desired volume size (in GiB).
+
+        encrypted
+            Indicates whether the volume should be encrypted. Encrypted EBS volumes must
+            be attached to instances that support Amazon EBS encryption. Volumes that are
+            created from encrypted snapshots are automatically encrypted. There is no way
+            to create an encrypted volume from an unencrypted snapshot or an unencrypted
+            volume from an encrypted snapshot.
 
     instance_monitoring
         Whether instances in group are launched with detailed monitoring.
@@ -221,48 +244,61 @@ def present(
     profile
         A dict with region, key and keyid, or a pillar key (string)
         that contains a dict with region, key and keyid.
-    '''
+    """
     if user_data and cloud_init:
-        raise SaltInvocationError('user_data and cloud_init are mutually'
-                                  ' exclusive options.')
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
-    exists = __salt__['boto_asg.launch_configuration_exists'](name, region,
-                                                              key, keyid,
-                                                              profile)
+        raise SaltInvocationError(
+            "user_data and cloud_init are mutually" " exclusive options."
+        )
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
+    exists = __salt__["boto_asg.launch_configuration_exists"](
+        name, region=region, key=key, keyid=keyid, profile=profile
+    )
     if not exists:
-        if __opts__['test']:
-            msg = 'Launch configuration set to be created.'
-            ret['comment'] = msg
-            ret['result'] = None
+        if __opts__["test"]:
+            msg = "Launch configuration set to be created."
+            ret["comment"] = msg
+            ret["result"] = None
             return ret
         if cloud_init:
-            user_data = __salt__['boto_asg.get_cloud_init_mime'](cloud_init)
+            user_data = __salt__["boto_asg.get_cloud_init_mime"](cloud_init)
         # TODO: Ensure image_id, key_name, security_groups and instance_profile
         # exist, or throw an invocation error.
-        created = __salt__['boto_asg.create_launch_configuration'](
-            name, image_id, key_name, security_groups, user_data,
-            instance_type, kernel_id, ramdisk_id, block_device_mappings,
-            instance_monitoring, spot_price, instance_profile_name,
-            ebs_optimized, associate_public_ip_address,
-            region, key, keyid, profile)
+        created = __salt__["boto_asg.create_launch_configuration"](
+            name,
+            image_id,
+            key_name=key_name,
+            vpc_id=vpc_id,
+            vpc_name=vpc_name,
+            security_groups=security_groups,
+            user_data=user_data,
+            instance_type=instance_type,
+            kernel_id=kernel_id,
+            ramdisk_id=ramdisk_id,
+            block_device_mappings=block_device_mappings,
+            delete_on_termination=delete_on_termination,
+            instance_monitoring=instance_monitoring,
+            spot_price=spot_price,
+            instance_profile_name=instance_profile_name,
+            ebs_optimized=ebs_optimized,
+            associate_public_ip_address=associate_public_ip_address,
+            region=region,
+            key=key,
+            keyid=keyid,
+            profile=profile,
+        )
         if created:
-            ret['changes']['old'] = None
-            ret['changes']['new'] = name
+            ret["changes"]["old"] = None
+            ret["changes"]["new"] = name
         else:
-            ret['result'] = False
-            ret['comment'] = 'Failed to create launch configuration.'
+            ret["result"] = False
+            ret["comment"] = "Failed to create launch configuration."
     else:
-        ret['comment'] = 'Launch configuration present.'
+        ret["comment"] = "Launch configuration present."
     return ret
 
 
-def absent(
-        name,
-        region=None,
-        key=None,
-        keyid=None,
-        profile=None):
-    '''
+def absent(name, region=None, key=None, keyid=None, profile=None):
+    """
     Ensure the named launch configuration is deleted.
 
     name
@@ -280,25 +316,26 @@ def absent(
     profile
         A dict with region, key and keyid, or a pillar key (string)
         that contains a dict with region, key and keyid.
-    '''
-    ret = {'name': name, 'result': True, 'comment': '', 'changes': {}}
-    exists = __salt__['boto_asg.launch_configuration_exists'](name, region,
-                                                              key, keyid,
-                                                              profile)
+    """
+    ret = {"name": name, "result": True, "comment": "", "changes": {}}
+    exists = __salt__["boto_asg.launch_configuration_exists"](
+        name, region=region, key=key, keyid=keyid, profile=profile
+    )
     if exists:
-        if __opts__['test']:
-            ret['comment'] = 'Launch configuration set to be deleted.'
-            ret['result'] = None
+        if __opts__["test"]:
+            ret["comment"] = "Launch configuration set to be deleted."
+            ret["result"] = None
             return ret
-        deleted = __salt__['boto_asg.delete_launch_configuration'](
-            name, region, key, keyid, profile)
+        deleted = __salt__["boto_asg.delete_launch_configuration"](
+            name, region=region, key=key, keyid=keyid, profile=profile
+        )
         if deleted:
-            ret['changes']['old'] = name
-            ret['changes']['new'] = None
-            ret['comment'] = 'Deleted launch configuration.'
+            ret["changes"]["old"] = name
+            ret["changes"]["new"] = None
+            ret["comment"] = "Deleted launch configuration."
         else:
-            ret['result'] = False
-            ret['comment'] = 'Failed to delete launch configuration.'
+            ret["result"] = False
+            ret["comment"] = "Failed to delete launch configuration."
     else:
-        ret['comment'] = 'Launch configuration does not exist.'
+        ret["comment"] = "Launch configuration does not exist."
     return ret
