@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 State modules to interact with Junos devices.
 ==============================================
 
@@ -12,31 +12,47 @@ State modules to interact with Junos devices.
     use the latest salt code from github until the next release.
 
 Refer to :mod:`junos <salt.proxy.junos>` for information on connecting to junos proxy.
-'''
+"""
 # Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
+from functools import wraps
 
 log = logging.getLogger()
 
 
-def rpc(name, dest=None, format='xml', args=None, **kwargs):
-    '''
+def resultdecorator(function):
+    @wraps(function)
+    def wrapper(*args, **kwargs):
+        ret = function(*args, **kwargs)
+        ret["result"] = ret["changes"]["out"]
+        return ret
+
+    return wrapper
+
+
+@resultdecorator
+def rpc(name, dest=None, format="xml", args=None, **kwargs):
+    """
     Executes the given rpc. The returned data can be stored in a file
     by specifying the destination path with dest as an argument
 
     .. code-block:: yaml
 
         get-interface-information:
-            junos:
-              - rpc
+            junos.rpc:
               - dest: /home/user/rpc.log
               - interface_name: lo0
 
+        fetch interface information with terse:
+            junos.rpc:
+                - name: get-interface-information
+                - terse: True
 
     Parameters:
       Required
-        * cmd:
+        * name:
           The rpc to be executed. (default = None)
       Optional
         * dest:
@@ -48,7 +64,7 @@ def rpc(name, dest=None, format='xml', args=None, **kwargs):
           The format in which the rpc reply must be stored in file specified in the dest
           (used only when dest is specified) (default = xml)
         * kwargs: keyworded arguments taken by rpc call like-
-            * timeout:
+            * timeout: 30
               Set NETCONF RPC timeout. Can be used for commands which
               take a while to execute. (default= 30 seconds)
             * filter:
@@ -57,29 +73,26 @@ def rpc(name, dest=None, format='xml', args=None, **kwargs):
               Amount of information you want.
             * interface_name:
               Name of the interface whose information you want.
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
     if args is not None:
-        ret['changes'] = __salt__['junos.rpc'](
-            name,
-            dest,
-            format,
-            *args,
-            **kwargs)
+        ret["changes"] = __salt__["junos.rpc"](
+            name, dest=dest, format=format, args=args, **kwargs
+        )
     else:
-        ret['changes'] = __salt__['junos.rpc'](name, dest, format, **kwargs)
+        ret["changes"] = __salt__["junos.rpc"](name, dest=dest, format=format, **kwargs)
     return ret
 
 
+@resultdecorator
 def set_hostname(name, **kwargs):
-    '''
+    """
     Changes the hostname of the device.
 
     .. code-block:: yaml
 
             device_name:
-              junos:
-                - set_hostname
+              junos.set_hostname:
                 - comment: "Host-name set via saltstack."
 
 
@@ -98,21 +111,21 @@ def set_hostname(name, **kwargs):
               If this option is specified, the commit will be rollbacked in \
               the given time unless the commit is confirmed.
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.set_hostname'](name, **kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.set_hostname"](name, **kwargs)
     return ret
 
 
+@resultdecorator
 def commit(name, **kwargs):
-    '''
+    """
     Commits the changes loaded into the candidate configuration.
 
     .. code-block:: yaml
 
             commit the changes:
-              junos:
-                - commit
+              junos.commit:
                 - confirm: 10
 
 
@@ -141,21 +154,21 @@ def commit(name, **kwargs):
               the new configuration.
             * detail:
               When true return commit detail.
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.commit'](**kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.commit"](**kwargs)
     return ret
 
 
+@resultdecorator
 def rollback(name, id, **kwargs):
-    '''
+    """
     Rollbacks the committed changes.
 
     .. code-block:: yaml
 
             rollback the changes:
-              junos:
-                - rollback
+              junos.rollback:
                 - id: 5
 
     Parameters:
@@ -175,74 +188,82 @@ def rollback(name, id, **kwargs):
             * diffs_file:
               Path to the file where any diffs will be written. (default = None)
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.rollback'](id, **kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.rollback"](id=id, **kwargs)
     return ret
 
 
-def diff(name, d_id):
-    '''
+@resultdecorator
+def diff(name, d_id=0, **kwargs):
+    """
+    .. versionchanged:: 3001
+
     Gets the difference between the candidate and the current configuration.
 
     .. code-block:: yaml
 
             get the diff:
-              junos:
-                - diff
-                - id: 10
+              junos.diff:
+                - d_id: 10
 
     Parameters:
       Optional
-        * id:
-          The rollback id value [0-49]. (default = 0)
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.diff'](d_id)
+        * d_id:
+          The rollback diff id (d_id) value [0-49]. (default = 0)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.diff"](id=d_id, **kwargs)
     return ret
 
 
-def cli(name, format='text', **kwargs):
-    '''
+@resultdecorator
+def cli(name, **kwargs):
+    """
     Executes the CLI commands and reuturns the text output.
 
     .. code-block:: yaml
 
             show version:
-              junos:
-                - cli
+              junos.cli:
                 - format: xml
 
+            get software version of device:
+              junos.cli:
+                - name: show version
+                - format: text
+                - dest: /home/user/show_version.log
+
     Parameters:
       Required
-        * command:
-          The command that need to be executed on Junos CLI. (default = None)
+        * name:
+          The command that need to be executed on Junos CLI.
       Optional
-        * format:
-          Format in which to get the CLI output. (text or xml, \
-            default = 'text')
         * kwargs: Keyworded arguments which can be provided like-
+            * format:
+              Format in which to get the CLI output. (text or xml, \
+                default = 'text')
             * timeout:
               Set NETCONF RPC timeout. Can be used for commands which
               take a while to execute. (default = 30 seconds)
             * dest:
               The destination file where the CLI output can be stored.\
                (default = None)
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.cli'](name, format, **kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.cli"](name, **kwargs)
     return ret
 
 
+@resultdecorator
 def shutdown(name, **kwargs):
-    '''
+    """
     Shuts down the device.
 
     .. code-block:: yaml
 
             shut the device:
-              junos:
-                - shutdown
+              junos.shutdown:
                 - in_min: 10
 
     Parameters:
@@ -254,32 +275,31 @@ def shutdown(name, **kwargs):
               Specify time for reboot. (To be used only if reboot=yes)
             * in_min:
               Specify delay in minutes for shutdown
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.shutdown'](**kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.shutdown"](**kwargs)
     return ret
 
 
+@resultdecorator
 def install_config(name, **kwargs):
-    '''
+    """
     Loads and commits the configuration provided.
 
     .. code-block:: yaml
 
             Install the mentioned config:
-              junos:
-                - install_config
-                - path: salt//configs/interface.set
+              junos.install_config:
+                - name: salt://configs/interface.set
                 - timeout: 100
-                - diffs_file: 'var/log/diff'
+                - diffs_file: '/var/log/diff'
 
 
     .. code-block:: yaml
 
             Install the mentioned config:
-              junos:
-                - install_config
-                - template_path: salt//configs/interface.set
+              junos.install_config:
+                - path: salt://configs/interface.set
                 - timeout: 100
                 - template_vars:
                     interface_name: lo0
@@ -302,12 +322,14 @@ def install_config(name, **kwargs):
       execute.
 
     overwrite : False
-      Set to ``True`` if you want this file is to completely replace the
-       configuration file.
+        Set to ``True`` if you want this file is to completely replace the
+        configuration file. Sets action to override
 
-    replace : False
-      Specify whether the configuration file uses "replace:" statements.  Only
-      those statements under the 'replace' tag will be changed.
+        .. note:: This option cannot be used if **format** is "set".
+
+    merge : False
+        If set to ``True`` will set the load-config action to merge.
+        the default load-config action is 'replace' for xml/json/text config
 
     comment
       Provide a comment to the commit. (default = None)
@@ -325,14 +347,15 @@ def install_config(name, **kwargs):
           The file will be stored on the proxy minion. To push the files to the
           master use :py:func:`cp.push <salt.modules.cp.push>`.
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.install_config'](name, **kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.install_config"](name, **kwargs)
     return ret
 
 
+@resultdecorator
 def zeroize(name):
-    '''
+    """
     Resets the device to default factory settings.
 
     .. code-block:: yaml
@@ -341,22 +364,22 @@ def zeroize(name):
               junos.zeroize
 
     name: can be anything
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.zeroize']()
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.zeroize"]()
     return ret
 
 
+@resultdecorator
 def install_os(name, **kwargs):
-    '''
+    """
     Installs the given image on the device. After the installation is complete
     the device is rebooted, if reboot=True is given as a keyworded argument.
 
     .. code-block:: yaml
 
             salt://images/junos_image.tgz:
-              junos:
-                - install_os
+              junos.install_os:
                 - timeout: 100
                 - reboot: True
 
@@ -376,21 +399,21 @@ def install_os(name, **kwargs):
               When True the software package will not be SCP’d to the device. \
               (default = False)
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.install_os'](name, **kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.install_os"](name, **kwargs)
     return ret
 
 
+@resultdecorator
 def file_copy(name, dest=None, **kwargs):
-    '''
+    """
     Copies the file from the local device to the junos device.
 
     .. code-block:: yaml
 
             /home/m2/info.txt:
-              junos:
-                - file_copy
+              junos.file_copy:
                 - dest: info_copy.txt
 
     Parameters:
@@ -399,14 +422,15 @@ def file_copy(name, dest=None, **kwargs):
           The sorce path where the file is kept.
         * dest:
           The destination path where the file will be copied.
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.file_copy'](name, dest, **kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.file_copy"](name, dest, **kwargs)
     return ret
 
 
+@resultdecorator
 def lock(name):
-    '''
+    """
     Attempts an exclusive lock on the candidate configuration. This
     is a non-blocking call.
 
@@ -420,14 +444,15 @@ def lock(name):
             lock the config:
               junos.lock
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.lock']()
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.lock"]()
     return ret
 
 
+@resultdecorator
 def unlock(name):
-    '''
+    """
     Unlocks the candidate configuration.
 
     .. code-block:: yaml
@@ -435,32 +460,37 @@ def unlock(name):
             unlock the config:
               junos.unlock
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.unlock']()
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.unlock"]()
     return ret
 
 
+@resultdecorator
 def load(name, **kwargs):
-    '''
+    """
     Loads the configuration provided onto the junos device.
 
     .. code-block:: yaml
 
-            Install the mentioned config:
-              junos:
-                - load
-                - path: salt//configs/interface.set
+        Install the mentioned config:
+          junos.load:
+            - name: salt://configs/interface.set
 
     .. code-block:: yaml
 
-            Install the mentioned config:
-              junos:
-                - load
-                - template_path: salt//configs/interface.set
-                - template_vars:
-                    interface_name: lo0
-                    description: Creating interface via SaltStack.
+        Install the mentioned config:
+          junos.load:
+            - name: salt://configs/interface.set
+            - template_vars:
+                interface_name: lo0
+                description: Creating interface via SaltStack.
+
+    Sample template:
+
+    .. code-block:: bash
+
+        set interfaces {{ interface_name }} unit 0
 
 
     name
@@ -474,12 +504,11 @@ def load(name, **kwargs):
         Set to ``True`` if you want this file is to completely replace the
         configuration file.
 
-    replace : False
-        Specify whether the configuration file uses "replace:" statements.
-        Only those statements under the 'replace' tag will be changed.
+        .. note:: This option cannot be used if **format** is "set".
 
-    format:
-      Determines the format of the contents.
+    merge : False
+        If set to ``True`` will set the load-config action to merge.
+        the default load-config action is 'replace' for xml/json/text config
 
     update : False
         Compare a complete loaded configuration against the candidate
@@ -496,14 +525,15 @@ def load(name, **kwargs):
       You may reference these variables in your template like so:
       {{ template_vars["var_name"] }}
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.load'](name, **kwargs)
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.load"](name, **kwargs)
     return ret
 
 
+@resultdecorator
 def commit_check(name):
-    '''
+    """
 
     Perform a commit check on the configuration.
 
@@ -512,7 +542,62 @@ def commit_check(name):
         perform commit check:
           junos.commit_check
 
-    '''
-    ret = {'name': name, 'changes': {}, 'result': True, 'comment': ''}
-    ret['changes'] = __salt__['junos.commit_check']()
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.commit_check"]()
+    return ret
+
+
+@resultdecorator
+def get_table(name, table, table_file, **kwargs):
+    """
+    .. versionadded:: 3001
+
+    Retrieve data from a Junos device using Tables/Views
+
+    .. code-block:: yaml
+
+        get route details:
+          junos.get_table:
+            - table: RouteTable
+            - table_file: routes.yml
+
+        get interface details:
+          junos.get_table:
+            - table: EthPortTable
+            - table_file: ethport.yml
+            - table_args:
+                interface_name: ge-0/0/0
+
+    name (required)
+        task definition
+
+    table (required)
+        Name of PyEZ Table
+
+    file
+        YAML file that has the table specified in table parameter
+
+    path:
+        Path of location of the YAML file.
+        defaults to op directory in jnpr.junos.op
+
+    target:
+        if command need to run on FPC, can specify fpc target
+
+    key:
+        To overwrite key provided in YAML
+
+    key_items:
+        To select only given key items
+
+    filters:
+        To select only filter for the dictionary from columns
+
+    template_args:
+        key/value pair which should render Jinja template command
+
+    """
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
+    ret["changes"] = __salt__["junos.get_table"](table, table_file, **kwargs)
     return ret
