@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Boto3 Common Utils
 =================
@@ -6,10 +5,6 @@ Boto3 Common Utils
 Note: This module depends on the dicts packed by the loader and,
 therefore, must be accessed via the loader or from the __utils__ dict.
 
-The __utils__ dict will not be automatically available to execution modules
-until 2015.8.0. The `salt.utils.compat.pack_dunder` helper function
-provides backwards compatibility.
-
 This module provides common functionality for the boto execution modules.
 The expected usage is to call `apply_funcs` from the `__virtual__` function
 of the module. This will bring properly initilized partials of  `_get_conn`
@@ -20,9 +15,6 @@ Example Usage:
     .. code-block:: python
 
         def __virtual__():
-            # only required in 2015.2
-            salt.utils.compat.pack_dunder(__name__)
-
             __utils__['boto.apply_funcs'](__name__, 'vpc')
 
         def test():
@@ -32,8 +24,6 @@ Example Usage:
 .. versionadded:: 2015.8.0
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import hashlib
 import logging
@@ -43,12 +33,8 @@ from functools import partial
 import salt.utils.stringutils
 import salt.utils.versions
 from salt.exceptions import SaltInvocationError
-from salt.ext import six
-
-# Import salt libs
 from salt.ext.six.moves import range  # pylint: disable=import-error,redefined-builtin
 
-# Import third party libs
 # pylint: disable=import-error
 try:
     # pylint: disable=import-error
@@ -97,7 +83,7 @@ def _option(value):
 
 def _get_profile(service, region, key, keyid, profile):
     if profile:
-        if isinstance(profile, six.string_types):
+        if isinstance(profile, str):
             _profile = _option(profile)
         elif isinstance(profile, dict):
             _profile = profile
@@ -117,11 +103,10 @@ def _get_profile(service, region, key, keyid, profile):
     if not keyid and _option(service + ".keyid"):
         keyid = _option(service + ".keyid")
 
-    label = "boto_{0}:".format(service)
+    label = "boto_{}:".format(service)
     if keyid:
         hash_string = region + keyid + key
-        if six.PY3:
-            hash_string = salt.utils.stringutils.to_bytes(hash_string)
+        hash_string = salt.utils.stringutils.to_bytes(hash_string)
         cxkey = label + hashlib.md5(hash_string).hexdigest()
     else:
         cxkey = label + region
@@ -152,16 +137,16 @@ def cache_id(
 
     cxkey, _, _, _ = _get_profile(service, region, key, keyid, profile)
     if sub_resource:
-        cxkey = "{0}:{1}:{2}:id".format(cxkey, sub_resource, name)
+        cxkey = "{}:{}:{}:id".format(cxkey, sub_resource, name)
     else:
-        cxkey = "{0}:{1}:id".format(cxkey, name)
+        cxkey = "{}:{}:id".format(cxkey, name)
 
     if invalidate:
         if cxkey in __context__:
             del __context__[cxkey]
             return True
         elif resource_id in __context__.values():
-            ctx = dict((k, v) for k, v in __context__.items() if v != resource_id)
+            ctx = {k: v for k, v in __context__.items() if v != resource_id}
             __context__.clear()
             __context__.update(ctx)
             return True
@@ -211,15 +196,15 @@ def get_connection(
             aws_access_key_id=keyid, aws_secret_access_key=key, region_name=region
         )
         if session is None:
-            raise SaltInvocationError('Region "{0}" is not ' "valid.".format(region))
+            raise SaltInvocationError('Region "{}" is not ' "valid.".format(region))
         conn = session.client(module)
         if conn is None:
-            raise SaltInvocationError('Region "{0}" is not ' "valid.".format(region))
+            raise SaltInvocationError('Region "{}" is not ' "valid.".format(region))
     except boto.exception.NoAuthHandlerFound:
         raise SaltInvocationError(
             "No authentication credentials found when "
-            "attempting to make boto {0} connection to "
-            'region "{1}".'.format(service, region)
+            "attempting to make boto {} connection to "
+            'region "{}".'.format(service, region)
         )
     __context__[cxkey] = conn
     return conn
@@ -252,24 +237,7 @@ def get_error(e):
     aws = {}
 
     message = ""
-    if six.PY2:
-        if hasattr(e, "status"):
-            aws["status"] = e.status
-        if hasattr(e, "reason"):
-            aws["reason"] = e.reason
-        if six.text_type(e) != "":
-            aws["message"] = six.text_type(e)
-        if hasattr(e, "error_code") and e.error_code is not None:
-            aws["code"] = e.error_code
-
-        if "message" in aws and "reason" in aws:
-            message = "{0}: {1}".format(aws["reason"], aws["message"])
-        elif "message" in aws:
-            message = aws["message"]
-        elif "reason" in aws:
-            message = aws["reason"]
-    elif six.PY3:
-        message = e.args[0]
+    message = e.args[0]
 
     r = {"message": message}
     if aws:
@@ -334,12 +302,9 @@ def ordered(obj):
     if isinstance(obj, (list, tuple)):
         return sorted(ordered(x) for x in obj)
     elif isinstance(obj, dict):
-        return dict(
-            (six.text_type(k) if isinstance(k, six.string_types) else k, ordered(v))
-            for k, v in obj.items()
-        )
-    elif isinstance(obj, six.string_types):
-        return six.text_type(obj)
+        return {str(k) if isinstance(k, str) else k: ordered(v) for k, v in obj.items()}
+    elif isinstance(obj, str):
+        return str(obj)
     return obj
 
 
