@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 :maintainer:    SaltStack
 :maturity:      new
@@ -8,7 +7,6 @@ Utilities supporting modules for Hashicorp Vault. Configuration instructions are
 documented in the execution module docs.
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
 
 import base64
 import logging
@@ -58,14 +56,14 @@ def _get_token_and_url_from_master():
     # When rendering pillars, the module executes on the master, but the token
     # should be issued for the minion, so that the correct policies are applied
     if __opts__.get("__role", "minion") == "minion":
-        private_key = "{0}/minion.pem".format(pki_dir)
+        private_key = "{}/minion.pem".format(pki_dir)
         log.debug("Running on minion, signing token request with key %s", private_key)
         signature = base64.b64encode(salt.crypt.sign_message(private_key, minion_id))
         result = __salt__["publish.runner"](
             "vault.generate_token", arg=[minion_id, signature, False, ttl, uses]
         )
     else:
-        private_key = "{0}/master.pem".format(pki_dir)
+        private_key = "{}/master.pem".format(pki_dir)
         log.debug(
             "Running on master, signing token request for %s with key %s",
             minion_id,
@@ -126,7 +124,7 @@ def get_vault_connection():
                 if _selftoken_expired():
                     log.debug("Vault token expired. Recreating one")
                     # Requesting a short ttl token
-                    url = "{0}/v1/auth/approle/login".format(__opts__["vault"]["url"])
+                    url = "{}/v1/auth/approle/login".format(__opts__["vault"]["url"])
                     payload = {"role_id": __opts__["vault"]["auth"]["role_id"]}
                     if "secret_id" in __opts__["vault"]["auth"]:
                         payload["secret_id"] = __opts__["vault"]["auth"]["secret_id"]
@@ -140,7 +138,7 @@ def get_vault_connection():
             if __opts__["vault"]["auth"]["method"] == "wrapped_token":
                 verify = __opts__["vault"].get("verify", None)
                 if _wrapped_token_valid():
-                    url = "{0}/v1/sys/wrapping/unwrap".format(__opts__["vault"]["url"])
+                    url = "{}/v1/sys/wrapping/unwrap".format(__opts__["vault"]["url"])
                     headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
                     response = requests.post(url, headers=headers, verify=verify)
                     if response.status_code != 200:
@@ -157,7 +155,7 @@ def get_vault_connection():
                 "ttl": 3600,
             }
         except KeyError as err:
-            errmsg = 'Minion has "vault" config section, but could not find key "{0}" within'.format(
+            errmsg = 'Minion has "vault" config section, but could not find key "{}" within'.format(
                 err
             )
             raise salt.exceptions.CommandExecutionError(errmsg)
@@ -229,7 +227,7 @@ def write_cache(connection):
         with salt.utils.files.fpopen(cache_file, "w", mode=0o600) as fp_:
             fp_.write(salt.utils.json.dumps(connection))
         return True
-    except (IOError, OSError):
+    except OSError:
         log.error(
             "Failed to cache vault information", exc_info_on_loglevel=logging.DEBUG
         )
@@ -308,7 +306,7 @@ def make_request(
         except (TypeError, AttributeError):
             # Don't worry about setting verify if it doesn't exist
             pass
-    url = "{0}/{1}".format(vault_url, resource)
+    url = "{}/{}".format(vault_url, resource)
     headers = {"X-Vault-Token": str(token), "Content-Type": "application/json"}
     response = requests.request(method, url, headers=headers, **args)
     if not response.ok and response.json().get("errors", None) == ["permission denied"]:
@@ -334,9 +332,9 @@ def make_request(
 
     # Decrement vault uses, only on secret URL lookups and multi use tokens
     if (
-        not connection.get("unlimited_use_token")
+        "uses" in connection
+        and not connection.get("unlimited_use_token")
         and not resource.startswith("v1/sys")
-        and not resource.startswith("v1/sec")
     ):
         log.debug("Decrementing Vault uses on limited token for url: %s", resource)
         connection["uses"] -= 1
@@ -363,7 +361,7 @@ def _selftoken_expired():
     """
     try:
         verify = __opts__["vault"].get("verify", None)
-        url = "{0}/v1/auth/token/lookup-self".format(__opts__["vault"]["url"])
+        url = "{}/v1/auth/token/lookup-self".format(__opts__["vault"]["url"])
         if "token" not in __opts__["vault"]["auth"]:
             return True
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
@@ -373,7 +371,7 @@ def _selftoken_expired():
         return False
     except Exception as e:  # pylint: disable=broad-except
         raise salt.exceptions.CommandExecutionError(
-            "Error while looking up self token : {0}".format(e)
+            "Error while looking up self token : {}".format(e)
         )
 
 
@@ -383,7 +381,7 @@ def _wrapped_token_valid():
     """
     try:
         verify = __opts__["vault"].get("verify", None)
-        url = "{0}/v1/sys/wrapping/lookup".format(__opts__["vault"]["url"])
+        url = "{}/v1/sys/wrapping/lookup".format(__opts__["vault"]["url"])
         if "token" not in __opts__["vault"]["auth"]:
             return False
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
@@ -393,7 +391,7 @@ def _wrapped_token_valid():
         return True
     except Exception as e:  # pylint: disable=broad-except
         raise salt.exceptions.CommandExecutionError(
-            "Error while looking up wrapped token : {0}".format(e)
+            "Error while looking up wrapped token : {}".format(e)
         )
 
 
@@ -410,9 +408,11 @@ def is_v2(path):
         # metadata lookup failed. Simply return not v2
         return ret
     ret["type"] = path_metadata.get("type", "kv")
-    if ret["type"] == "kv" and path_metadata.get("options", {}).get("version", "1") in [
-        "2"
-    ]:
+    if (
+        ret["type"] == "kv"
+        and path_metadata["options"] is not None
+        and path_metadata.get("options", {}).get("version", "1") in ["2"]
+    ):
         ret["v2"] = True
         ret["data"] = _v2_the_path(path, path_metadata.get("path", path))
         ret["metadata"] = _v2_the_path(
@@ -481,7 +481,7 @@ def _get_secret_path_metadata(path):
     else:
         log.debug("Fetching metadata for %s", path)
         try:
-            url = "v1/sys/internal/ui/mounts/{0}".format(path)
+            url = "v1/sys/internal/ui/mounts/{}".format(path)
             response = make_request("GET", url)
             if response.ok:
                 response.raise_for_status()
